[open-ils-commits] [GIT] Evergreen ILS branch master updated. fa6b3464a10de71e45666cdb9191b80fca9f8164

Evergreen Git git at git.evergreen-ils.org
Wed Nov 8 13:46:15 EST 2017


This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Evergreen ILS".

The branch, master has been updated
       via  fa6b3464a10de71e45666cdb9191b80fca9f8164 (commit)
      from  1c4b73fc3d5b7267f45a479c4f53b53e035b27e4 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
commit fa6b3464a10de71e45666cdb9191b80fca9f8164
Author: Mike Rylander <mrylander at gmail.com>
Date:   Wed Nov 1 18:22:21 2017 -0400

    LP#1704396: reset the facet alarm timer
    
    When using alarm() one must reset the timer via alarm(0) or incur the wrath
    of the spurious signal.
    
    Signed-off-by: Mike Rylander <mrylander at gmail.com>
    Signed-off-by: Jason Stephenson <jason at sigio.com>

diff --git a/Open-ILS/src/perlmods/lib/OpenILS/Application/Search/Biblio.pm b/Open-ILS/src/perlmods/lib/OpenILS/Application/Search/Biblio.pm
index 4a0336d..06ec97d 100644
--- a/Open-ILS/src/perlmods/lib/OpenILS/Application/Search/Biblio.pm
+++ b/Open-ILS/src/perlmods/lib/OpenILS/Application/Search/Biblio.pm
@@ -1364,11 +1364,13 @@ sub retrieve_cached_facets {
 
     eval {
         local $SIG{ALRM} = sub {die};
-        alarm(4); # we'll sleep for as much as 4s
+        alarm(10); # we'll sleep for as much as 10s
         do {
             die if $cache->get_cache($key . '_COMPLETE');
         } while (sleep(0.05));
+        alarm(0);
     };
+    alarm(0);
 
     my $blob = $cache->get_cache($key) || {};
 

-----------------------------------------------------------------------

Summary of changes:
 .../lib/OpenILS/Application/Search/Biblio.pm       |    4 +++-
 1 files changed, 3 insertions(+), 1 deletions(-)


hooks/post-receive
-- 
Evergreen ILS


More information about the open-ils-commits mailing list